@@ -16,7 +16,7 @@
 """
 import base64
 
-VERSION = "1.282"
+VERSION = "1.284"
 
 PATH_COMMANDS = [
     "bin/create-shell-archive.sh",
@@ -102,6 +102,7 @@ NDT_ONLY = [
     "yaml-to-yaml=n_utils.cli:yaml_to_yaml",
     "upsert-codebuild-projects=n_utils.cli:cli_upsert_codebuild_projects",
     "upsert-dns-record=n_utils.cli:upsert_dns_record",
+    "update-sso-profile=n_utils.profile_util:cli_update_sso_profile",
     "deploy-connect=n_utils.cli:deploy_connect_contact_flows",
     "export-connect-contact-flow=n_utils.cli:export_connect_contact_flow",
     "list-connect-contact-flows=n_utils.cli:list_connect_contact_flows",
@@ -150,7 +151,7 @@ def _to_str(data):
     if callable(decode_method):
         try:
             ret = data.decode()
-        except:
+        except Exception:
             ret = _to_str(base64.b64encode(data))
     return str(ret)
 
