@@ -10,6 +10,7 @@ import argcomplete
 from argcomplete.completers import ChoicesCompleter
 from dateutil.parser import parse
 from dateutil.tz import tzutc
+from threadlocal_aws.clients import sso
 
 from n_utils.az_util import az_select_subscription
 from n_utils.bw_util import get_bwentry
@@ -32,9 +33,7 @@ def read_expiring_profiles():
         with open(credentials) as credfile:
             parser.read_file(credfile)
             for profile in parser.sections():
-                if parser.has_option(
-                    profile, "aws_session_expiration"
-                ) or parser.has_option(profile, "aws_expiration"):
+                if parser.has_option(profile, "aws_session_expiration") or parser.has_option(profile, "aws_expiration"):
                     ret.append(profile)
     return ret
 
@@ -56,17 +55,15 @@ def read_profiles(prefix=""):
         with open(config) as configfile:
             parser.read_file(configfile)
             for profile in parser.sections():
-                if (
-                    profile.startswith("profile ")
-                    and profile[8:] not in ret
-                    and profile[8:].startswith(prefix)
-                ):
+                if profile.startswith("profile ") and profile[8:] not in ret and profile[8:].startswith(prefix):
                     ret.append(profile[8:])
     return ret
 
-PROFILES= {}
+
+PROFILES = {}
 PROFILES_WITH_CREDS = {}
 
+
 def get_profile(profile, include_creds=True):
     home = expanduser("~")
     if include_creds and profile in PROFILES_WITH_CREDS:
@@ -113,12 +110,14 @@ def read_profile_expiry(profile, profile_type=None):
                     return parser.get(profile, "aws_session_expiration")
     return read_sso_profile_expiry(profile)
 
+
 def read_sso_profile_expiry(profile):
     profile_data = read_sso_profile(profile)
     if profile_data:
         return profile_data.get("expiresAt", "1970-01-01T00:00:00Z")[:-1] + ".000Z"
     return "1970-01-01T00:00:00.000Z"
 
+
 def read_sso_profile(profile):
     profile_data = get_profile(profile, include_creds=False)
     if "sso_start_url" in profile_data:
@@ -128,17 +127,30 @@ def read_sso_profile(profile):
             for filename in os.listdir(sso_cache):
                 full_file = os.path.join(sso_cache, filename)
                 if isfile(full_file) and access(full_file, R_OK):
-                    with open(full_file, "r") as cache_file:
+                    with open(full_file) as cache_file:
                         cache_json = json.load(cache_file)
-                        if cache_json and "startUrl" in cache_json and cache_json["startUrl"] == profile_data["sso_start_url"]:
+                        if (
+                            cache_json
+                            and "startUrl" in cache_json
+                            and cache_json["startUrl"] == profile_data["sso_start_url"]
+                        ):
                             return cache_json
     return {}
 
+
 def read_profile_expiry_epoc(profile, profile_type=None):
     return _epoc_secs(parse(read_profile_expiry(profile, profile_type=profile_type)).replace(tzinfo=tzutc()))
 
+
+def check_profile_expired(profile, profile_type=None):
+    return read_profile_expiry_epoc(profile, profile_type) < _epoc_secs(datetime.now(tzutc()))
+
+
 def print_aws_profiles():
-    """Prints profile names from credentials file (~/.aws/credentials) and the conf file (~/.aws/conf) for autocomplete tools"""
+    """
+    Prints profile names from credentials file (~/.aws/credentials),
+    and the conf file (~/.aws/conf) for autocomplete tools.
+    """
     parser = argparse.ArgumentParser(description=print_aws_profiles.__doc__)
     if "_ARGCOMPLETE" in os.environ:
         parser.add_argument(
@@ -146,9 +158,7 @@ def print_aws_profiles():
         ).completer = ChoicesCompleter(read_profiles())
         argcomplete.autocomplete(parser)
     else:
-        parser.add_argument(
-            "prefix", help="Prefix of profiles to print", default="", nargs="?"
-        )
+        parser.add_argument("prefix", help="Prefix of profiles to print", default="", nargs="?")
     args = parser.parse_args()
     print(" ".join(read_profiles(prefix=args.prefix)))
 
@@ -168,9 +178,9 @@ def profile_to_env():
         help="Output also the role given here as the target role for the profile",
     )
     if "_ARGCOMPLETE" in os.environ:
-        parser.add_argument(
-            "profile", help="The profile to read profile info from"
-        ).completer = ChoicesCompleter(read_profiles())
+        parser.add_argument("profile", help="The profile to read profile info from").completer = ChoicesCompleter(
+            read_profiles()
+        )
         argcomplete.autocomplete(parser)
     else:
         parser.add_argument("profile", help="The profile to read profile info from")
@@ -186,36 +196,15 @@ def profile_to_env():
             parser = ConfigParser()
             with open(config) as configfile:
                 parser.read_file(configfile)
-                if profile_entry in parser.sections() and parser.has_option(
-                    profile_entry, "azure_default_role_arn"
-                ):
+                if profile_entry in parser.sections() and parser.has_option(profile_entry, "azure_default_role_arn"):
                     params.append(role_param)
-                    print(
-                        role_param
-                        + '="'
-                        + parser.get(profile_entry, "azure_default_role_arn")
-                        + '";'
-                    )
-                if profile_entry in parser.sections() and parser.has_option(
-                    profile_entry, "adfs_role_arn"
-                ):
+                    print(role_param + '="' + parser.get(profile_entry, "azure_default_role_arn") + '";')
+                if profile_entry in parser.sections() and parser.has_option(profile_entry, "adfs_role_arn"):
                     params.append(role_param)
-                    print(
-                        role_param
-                        + '="'
-                        + parser.get(profile_entry, "adfs_role_arn")
-                        + '";'
-                    )
-                if profile_entry in parser.sections() and parser.has_option(
-                    profile_entry, "lastpass_role_arn"
-                ):
+                    print(role_param + '="' + parser.get(profile_entry, "adfs_role_arn") + '";')
+                if profile_entry in parser.sections() and parser.has_option(profile_entry, "lastpass_role_arn"):
                     params.append(role_param)
-                    print(
-                        role_param
-                        + '="'
-                        + parser.get(profile_entry, "lastpass_role_arn")
-                        + '";'
-                    )
+                    print(role_param + '="' + parser.get(profile_entry, "lastpass_role_arn") + '";')
     if args.role_arn:
         params.append(role_param)
         print(role_param + '="' + args.role_arn + '";')
@@ -229,13 +218,7 @@ def print_profile(profile_name, params):
         upper_param = key.upper()
         if key == "aws_session_expiration" or key == "aws_expiration":
             d = parse(value)
-            print(
-                "AWS_SESSION_EXPIRATION_EPOC_"
-                + safe_profile
-                + '="'
-                + str(_epoc_secs(d))
-                + '";'
-            )
+            print("AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + '="' + str(_epoc_secs(d)) + '";')
             params.append("AWS_SESSION_EXPIRATION_EPOC_" + safe_profile)
         params.append(upper_param)
         if value.startswith('"'):
@@ -245,12 +228,14 @@ def print_profile(profile_name, params):
 
 
 def profile_expiry_to_env():
-    """Prints profile expiry from credentials file (~/.aws/credentials) as eval-able environment variables"""
+    """
+    Prints profile expiry from credentials file (~/.aws/credentials) as eval-able environment variables.
+    """
     parser = argparse.ArgumentParser(description=profile_expiry_to_env.__doc__)
     if "_ARGCOMPLETE" in os.environ:
-        parser.add_argument(
-            "profile", help="The profile to read expiry info from"
-        ).completer = ChoicesCompleter(read_expiring_profiles())
+        parser.add_argument("profile", help="The profile to read expiry info from").completer = ChoicesCompleter(
+            read_expiring_profiles()
+        )
         argcomplete.autocomplete(parser)
     else:
         parser.add_argument("profile", help="The profile to read expiry info from")
@@ -268,49 +253,80 @@ def print_profile_expiry(profile, expiry_epoc=None):
         epoc = _epoc_secs(parse(expiry).replace(tzinfo=tzutc()))
     print("AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + "=" + str(epoc))
     print("AWS_SESSION_EXPIRATION_" + safe_profile + "=" + expiry)
-    print(
-        "export AWS_SESSION_EXPIRATION_"
-        + safe_profile
-        + " AWS_SESSION_EXPIRATION_EPOC_"
-        + safe_profile
-        + ";"
-    )
+    print("export AWS_SESSION_EXPIRATION_" + safe_profile + " AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + ";")
 
 
 def cli_read_profile_expiry():
-    """Read expiry field from credentials file, which is there if the login happened
-    with aws-azure-login or another tool that implements the same logic (e.g. https://github.com/NitorCreations/adfs-aws-login)."""
+    """
+    Read expiry field from credentials file,
+    which is there if the login happened with aws-azure-login or another tool that implements the same logic
+    (e.g. https://github.com/NitorCreations/adfs-aws-login).
+    """
     parser = argparse.ArgumentParser(description=cli_read_profile_expiry.__doc__)
-    parser.add_argument(
-        "profile", help="The profile to read expiry info from"
-    ).completer = ChoicesCompleter(read_expiring_profiles())
+    parser.add_argument("profile", help="The profile to read expiry info from").completer = ChoicesCompleter(
+        read_expiring_profiles()
+    )
     argcomplete.autocomplete(parser)
     args = parser.parse_args()
     print(read_profile_expiry(args.profile))
 
 
+def cli_update_sso_profile():
+    """
+    Update current SSO-profile's session to ~/.aws/credentials.
+    Running this enables SSO-support for the Serverless Framework.
+    """
+    parser = argparse.ArgumentParser(description=cli_update_sso_profile.__doc__)
+    argcomplete.autocomplete(parser)
+    _ = parser.parse_args()
+    if "AWS_PROFILE" not in os.environ:
+        return
+    profile_name = os.environ["AWS_PROFILE"]
+    profile = get_profile(profile_name)
+    profile_type = resolve_profile_type(profile_name)
+    if check_profile_expired(profile=profile_name, profile_type=profile_type):
+        return
+    if profile_type == "sso":
+        cache_json = read_sso_profile(profile_name)
+        if "accessToken" in cache_json and cache_json["accessToken"]:
+            access_token = cache_json["accessToken"]
+            creds = sso(region=profile["sso_region"]).get_role_credentials(
+                roleName=profile["sso_role_name"], accountId=profile["sso_account_id"], accessToken=access_token
+            )
+            role_creds = creds["roleCredentials"]
+            update_profile(profile_name, role_creds)
+
+
 def update_profile(profile, creds):
     home = expanduser("~")
     credentials = join(home, ".aws", "credentials")
-    if exists(credentials):
-        parser = ConfigParser()
-        with open(credentials, "r") as credfile:
-            parser.read_file(credfile)
-            if profile not in parser.sections():
-                parser.add_section(profile)
-            parser.set(profile, "aws_access_key_id", creds["AccessKeyId"])
-            parser.set(profile, "aws_secret_access_key", creds["SecretAccessKey"])
-            parser.set(profile, "aws_session_token", creds["SessionToken"])
-            parser.set(
-                profile,
-                "aws_session_expiration",
-                creds["Expiration"].strftime("%Y-%m-%dT%H:%M:%S.%fZ"),
-            )
-            parser.set(
-                profile,
-                "aws_expiration",
-                creds["Expiration"].strftime("%Y-%m-%dT%H:%M:%S.%fZ"),
-            )
+    profile_type = resolve_profile_type(profile)
+    parser = ConfigParser()
+    if not exists(credentials):
+        with open(credentials, "w"):
+            pass
+    with open(credentials, "r") as credfile:
+        parser.read_file(credfile)
+        if profile not in parser.sections():
+            parser.add_section(profile)
+        if profile_type == "sso":
+            creds["AccessKeyId"] = creds["accessKeyId"]
+            creds["SecretAccessKey"] = creds["secretAccessKey"]
+            creds["SessionToken"] = creds["sessionToken"]
+            creds["Expiration"] = datetime.fromtimestamp(creds["expiration"] / 1000)
+        parser.set(profile, "aws_access_key_id", creds["AccessKeyId"])
+        parser.set(profile, "aws_secret_access_key", creds["SecretAccessKey"])
+        parser.set(profile, "aws_session_token", creds["SessionToken"])
+        parser.set(
+            profile,
+            "aws_session_expiration",
+            creds["Expiration"].strftime("%Y-%m-%dT%H:%M:%S.%fZ"),
+        )
+        parser.set(
+            profile,
+            "aws_expiration",
+            creds["Expiration"].strftime("%Y-%m-%dT%H:%M:%S.%fZ"),
+        )
     with open(credentials, "w") as credfile:
         parser.write(credfile)
 
@@ -331,7 +347,7 @@ def profiles_to_json():
     ret = OrderedDict()
     if exists(config):
         parser = ConfigParser()
-        with open(config, "r") as conffile:
+        with open(config) as conffile:
             parser.read_file(conffile)
             for section in parser.sections():
                 if section.startswith("profile "):
@@ -348,7 +364,7 @@ def update_profile_conf(profile, creds):
     profile_section = "profile " + profile
     if exists(config):
         parser = ConfigParser()
-        with open(config, "r") as conffile:
+        with open(config) as conffile:
             parser.read_file(conffile)
             if profile_section in parser.sections():
                 parser.remove_section(profile_section)
@@ -373,13 +389,11 @@ def store_bw_profile(bw_entry_name):
         credentials = join(home, ".aws", "credentials")
         if exists(credentials):
             parser = ConfigParser()
-            with open(credentials, "r") as credfile:
+            with open(credentials) as credfile:
                 parser.read_file(credfile)
                 if profile not in parser.sections():
                     parser.add_section(profile)
-                parser.set(
-                    profile, "aws_access_key_id", bw_entry.fields["aws_access_key_id"]
-                )
+                parser.set(profile, "aws_access_key_id", bw_entry.fields["aws_access_key_id"])
                 parser.set(
                     profile,
                     "aws_secret_access_key",
@@ -410,34 +424,20 @@ def cli_enable_profile():
     """Enable a configured profile. Simple IAM user, AzureAD, ADFS and ndt assume-role profiles are supported"""
     parser = argparse.ArgumentParser(description=cli_enable_profile.__doc__)
     type_select = parser.add_mutually_exclusive_group(required=False)
-    type_select.add_argument(
-        "-i", "--iam", action="store_true", help="IAM user type profile"
-    )
-    type_select.add_argument(
-        "-a", "--azure", action="store_true", help="Azure login type profile"
-    )
-    type_select.add_argument(
-        "-f", "--adfs", action="store_true", help="ADFS login type profile"
-    )
-    type_select.add_argument(
-        "-l", "--lastpass", action="store_true", help="Lastpass login type profile"
-    )
-    type_select.add_argument(
-        "-n", "--ndt", action="store_true", help="NDT assume role type profile"
-    )
+    type_select.add_argument("-i", "--iam", action="store_true", help="IAM user type profile")
+    type_select.add_argument("-a", "--azure", action="store_true", help="Azure login type profile")
+    type_select.add_argument("-f", "--adfs", action="store_true", help="ADFS login type profile")
+    type_select.add_argument("-l", "--lastpass", action="store_true", help="Lastpass login type profile")
+    type_select.add_argument("-n", "--ndt", action="store_true", help="NDT assume role type profile")
     type_select.add_argument(
         "-s",
         "--azure-subscription",
         action="store_true",
         help="Microsoft Azure subscription",
     )
-    type_select.add_argument(
-        "-o", "--sso", action="store_true", help="AWS SSO type profile"
-    )
+    type_select.add_argument("-o", "--sso", action="store_true", help="AWS SSO type profile")
     if "_ARGCOMPLETE" in os.environ:
-        parser.add_argument(
-            "profile", help="The profile to enable"
-        ).completer = ChoicesCompleter(read_profiles())
+        parser.add_argument("profile", help="The profile to enable").completer = ChoicesCompleter(read_profiles())
         argcomplete.autocomplete(parser)
     else:
         parser.add_argument("profile", help="The profile to enable")
@@ -482,21 +482,16 @@ def enable_profile(profile_type, profile):
     orig_profile = profile
     profile = re.sub("[^a-zA-Z0-9_-]", "_", profile)
     safe_profile = re.sub("[^A-Z0-9]", "_", profile.upper())
-    now = _epoc_secs(datetime.now(tzutc()))
-    expiry = now - 1000
+    profile_expired = check_profile_expired(profile, profile_type=profile_type)
     if profile_type == "iam":
         _print_profile_switch(profile)
-    elif (
-        profile_type == "azure" or profile_type == "adfs" or profile_type == "lastpass" or profile_type == "sso"
-    ):
+    elif profile_type == "azure" or profile_type == "adfs" or profile_type == "lastpass" or profile_type == "sso":
         _print_profile_switch(profile)
-        if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
-            expiry = int(os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile])
-        if expiry < now:
+        if profile_expired:
             expiry = read_profile_expiry_epoc(profile, profile_type=profile_type)
             if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
                 del os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile]
-        if expiry < now:
+        if profile_expired:
             bw_prefix = ""
             bw_entry = None
             lp_entry = None
@@ -515,21 +510,13 @@ def enable_profile(profile_type, profile):
                     bw_prefix = "AZURE_DEFAULT_PASSWORD='" + bw_entry.password + "' "
                 elif lp_entry:
                     bw_prefix = "AZURE_DEFAULT_PASSWORD='" + lp_entry.password + "' "
-                print(
-                    bw_prefix
-                    + "aws-azure-login --profile "
-                    + profile
-                    + gui_mode
-                    + " --no-prompt --no-sandbox"
-                )
+                print(bw_prefix + "npx aws-azure-login --profile " + profile + gui_mode + " --no-prompt --no-sandbox")
             elif profile_type == "adfs":
                 if bw_entry:
                     bw_prefix = "ADFS_DEFAULT_PASSWORD='" + bw_entry.password + "' "
                 elif lp_entry:
                     bw_prefix = "ADFS_DEFAULT_PASSWORD='" + lp_entry.password + "' "
-                print(
-                    bw_prefix + "adfs-aws-login --profile " + profile + " --no-prompt"
-                )
+                print(bw_prefix + "adfs-aws-login --profile " + profile + " --no-prompt")
             elif profile_type == "lastpass":
                 if bw_entry:
                     bw_prefix = "LASTPASS_DEFAULT_PASSWORD='" + bw_entry.password + "' "
@@ -538,27 +525,20 @@ def enable_profile(profile_type, profile):
                 elif lp_entry:
                     bw_prefix = "LASTPASS_DEFAULT_PASSWORD='" + lp_entry.password + "' "
                 if "ndt_mfa_token" in profile_data:
-                    bw_prefix += (
-                        "LASTPASS_DEFAULT_OTP='"
-                        + mfa_generate_code(profile_data["ndt_mfa_token"])
-                        + "' "
-                    )
-                print(
-                    bw_prefix
-                    + "lastpass-aws-login --profile "
-                    + profile
-                    + " --no-prompt"
-                )
+                    bw_prefix += "LASTPASS_DEFAULT_OTP='" + mfa_generate_code(profile_data["ndt_mfa_token"]) + "' "
+                print(bw_prefix + "lastpass-aws-login --profile " + profile + " --no-prompt")
             elif profile_type == "sso":
-                print("aws sso login --profile " + profile)
+                print("aws sso login --profile " + profile + ";")
+                print('eval "$(ndt update-sso-profile)"')
         elif "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile not in os.environ:
+            expiry = read_profile_expiry_epoc(profile, profile_type=profile_type)
             print_profile_expiry(profile, expiry_epoc=expiry)
     elif profile_type == "ndt":
         if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
             expiry = int(os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile])
-        if expiry < now:
+        if profile_expired:
             expiry = read_profile_expiry_epoc(profile)
-        if expiry < now:
+        if profile_expired:
             if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
                 print("unset AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + ";")
             profile_data = get_profile(profile)
@@ -592,10 +572,7 @@ def enable_profile(profile_type, profile):
             print_profile_expiry(profile, expiry_epoc=expiry)
         _print_profile_switch(profile)
     elif profile_type == "azure-subscription":
-        if not (
-            "AZURE_SUBSCRIPTION" in os.environ
-            and os.environ["AZURE_SUBSCRIPTION"] == orig_profile
-        ):
+        if not ("AZURE_SUBSCRIPTION" in os.environ and os.environ["AZURE_SUBSCRIPTION"] == orig_profile):
             subscription_id = az_select_subscription(orig_profile)
             if subscription_id:
                 print('AZURE_SUBSCRIPTION="' + orig_profile + '";')
@@ -605,16 +582,14 @@ def enable_profile(profile_type, profile):
 
 def _print_profile_switch(profile):
     unset = []
+    profile_type = resolve_profile_type(profile_name=profile)
     for env in ["AWS_SESSION_TOKEN", "AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY"]:
         if env in os.environ:
             unset.append(env)
     if unset:
         print("unset " + " ".join(unset) + ";")
     set_env = []
-    if (
-        "AWS_DEFAULT_PROFILE" not in os.environ
-        or os.environ["AWS_DEFAULT_PROFILE"] != profile
-    ):
+    if "AWS_DEFAULT_PROFILE" not in os.environ or os.environ["AWS_DEFAULT_PROFILE"] != profile:
         set_env.append("AWS_DEFAULT_PROFILE")
     if "AWS_PROFILE" not in os.environ or os.environ["AWS_PROFILE"] != profile:
         set_env.append("AWS_PROFILE")
@@ -622,12 +597,13 @@ def _print_profile_switch(profile):
         for param in set_env:
             print(param + '="' + profile + '";')
         print("export " + " ".join(set_env) + ";")
+        if profile_type == "sso":
+            print('eval "$(ndt update-sso-profile)"')
 
 
 def _epoc_to_str(epoc):
     return datetime.utcfromtimestamp(epoc).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
 
+
 def _epoc_secs(d):
-    return int(
-        (d - datetime.utcfromtimestamp(0).replace(tzinfo=tzutc())).total_seconds()
-    )
+    return int((d - datetime.utcfromtimestamp(0).replace(tzinfo=tzutc())).total_seconds())
