@@ -14,10 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-""" Utilities to work with instances made by nameless-deploy-tools stacks
-"""
+"""Utilities to work with instances made by nameless-deploy-tools stacks."""
 
-import io
 import json
 import os
 import random
@@ -26,12 +24,10 @@ import shutil
 import string
 import tempfile
 import time
-from builtins import object, range, str
 from collections import OrderedDict
 from copy import deepcopy
 from operator import itemgetter
 
-import six
 from botocore.exceptions import ClientError
 from ec2_utils.instance_info import info, is_ec2, resolve_account, stack_params_and_outputs_and_stack
 from n_vault import Vault
@@ -44,21 +40,17 @@ from n_utils.mfa_utils import mfa_generate_code, mfa_read_token
 NoneType = type(None)
 ACCOUNT_ID = None
 ROLE_NAME = None
-INSTANCE_IDENTITY_URL = (
-    "http://169.254.169.254/latest/dynamic/instance-identity/document"
-)
+INSTANCE_IDENTITY_URL = "http://169.254.169.254/latest/dynamic/instance-identity/document"
 USER_DATA_URL = "http://169.254.169.254/latest/user-data"
 INSTANCE_DATA_LINUX = "/opt/nameless/instance-data.json"
 INSTANCE_DATA_WIN = "C:/nameless/instance-data.json"
 
-dthandler = (
-    lambda obj: obj.isoformat()
-    if hasattr(obj, "isoformat")
-    else json.JSONEncoder().default(obj)
-)
+
+def dthandler(obj):
+    return obj.isoformat() if hasattr(obj, "isoformat") else json.JSONEncoder().default(obj)
 
 
-class ParamNotAvailable(object):
+class ParamNotAvailable:
     def __init__(self):
         return
 
@@ -66,9 +58,7 @@ class ParamNotAvailable(object):
         return "PARAM_NOT_AVAILABLE"
 
 
-def id_generator(
-    size=10, chars=string.ascii_uppercase + string.digits + string.ascii_lowercase
-):
+def id_generator(size=10, chars=string.ascii_uppercase + string.digits + string.ascii_lowercase):
     return "".join(random.choice(chars) for _ in range(size))
 
 
@@ -96,9 +86,9 @@ def assumed_role_name():
     global ROLE_NAME
     if not ROLE_NAME:
         try:
-            roleArn = sts().get_caller_identity()["Arn"]
-            if ":assumed-role/" in roleArn:
-                ROLE_NAME = roleArn.split("/")[1]
+            role_arn = sts().get_caller_identity()["Arn"]
+            if ":assumed-role/" in role_arn:
+                ROLE_NAME = role_arn.split("/")[1]
         except BaseException:
             pass
     return ROLE_NAME
@@ -106,9 +96,7 @@ def assumed_role_name():
 
 def share_to_another_region(ami_id, regn, ami_name, account_ids, timeout_sec=900):
     if not regn == region():
-        resp = ec2(region=regn).copy_image(
-            SourceRegion=region(), SourceImageId=ami_id, Name=ami_name
-        )
+        resp = ec2(region=regn).copy_image(SourceRegion=region(), SourceImageId=ami_id, Name=ami_name)
         ami_id = resp["ImageId"]
     status = "initial"
     start = time.time()
@@ -116,11 +104,7 @@ def share_to_another_region(ami_id, regn, ami_name, account_ids, timeout_sec=900
         time.sleep(2)
         if time.time() - start > timeout_sec:
             raise Exception(
-                "Failed waiting for status 'available' for "
-                + ami_id
-                + " (timeout: "
-                + str(timeout_sec)
-                + ")"
+                "Failed waiting for status 'available' for " + ami_id + " (timeout: " + str(timeout_sec) + ")"
             )
         try:
             images_resp = ec2(region=regn).describe_images(ImageIds=[ami_id])
@@ -145,15 +129,11 @@ def _has_job_tag(image, image_name_prefix):
 
 def get_images(image_name_prefix, job_tag_function=_has_job_tag):
     image_name_prefix = re.sub(r"\W", "_", image_name_prefix)
-    ami_data = ec2().describe_images(
-        Filters=[{"Name": "tag-value", "Values": [image_name_prefix + "_*"]}]
-    )
+    ami_data = ec2().describe_images(Filters=[{"Name": "tag-value", "Values": [image_name_prefix + "_*"]}])
     if len(ami_data["Images"]) > 0:
         return [
             image
-            for image in sorted(
-                ami_data["Images"], key=itemgetter("CreationDate"), reverse=True
-            )
+            for image in sorted(ami_data["Images"], key=itemgetter("CreationDate"), reverse=True)
             if job_tag_function(image, image_name_prefix)
         ]
     else:
@@ -171,9 +151,7 @@ def promote_image(ami_id, job_name):
         ami_props.write("AMI_ID=" + ami_id + "\nNAME=" + ami_name + "\n")
     ec2().create_tags(
         Resources=[ami_id],
-        Tags=[
-            {"Key": image_name_prefix, "Value": image_name_prefix + "_" + build_number}
-        ],
+        Tags=[{"Key": image_name_prefix, "Value": image_name_prefix + "_" + build_number}],
     )
 
 
@@ -213,7 +191,7 @@ def interpolate_file(
     if use_vault:
         vault = Vault()
         vault_keys = vault.list_all()
-    with io.open(file_name, "r", encoding=encoding) as _infile:
+    with open(file_name, encoding=encoding) as _infile:
         with dstfile as _outfile:
             for line in _infile:
                 line = _process_line(line, params, vault, vault_keys)
@@ -252,34 +230,20 @@ def _apply_simple_regex(RE, line, params, vault, vault_keys):
 def expand_vars(line, params, vault, vault_keys):
     if isinstance(line, OrderedDict) or isinstance(line, dict):
         ret = OrderedDict(list(line.items()))
-        if "Fn::" in [
-            x[:4] for x in list(ret.keys()) if isinstance(x, six.string_types)
-        ]:
+        if "Fn::" in [x[:4] for x in list(ret.keys()) if isinstance(x, str)]:
             return expand_only_double_paranthesis_params(ret, params, vault, vault_keys)
         for key, value in list(line.items()):
-            if isinstance(key, six.string_types) and key.startswith("Fn::"):
-                new_value = expand_only_double_paranthesis_params(
-                    value, params, vault, vault_keys
-                )
-                ret = OrderedDict(
-                    [
-                        (key, new_value) if k == key else (k, v)
-                        for k, v in list(ret.items())
-                    ]
-                )
+            if isinstance(key, str) and key.startswith("Fn::"):
+                new_value = expand_only_double_paranthesis_params(value, params, vault, vault_keys)
+                ret = OrderedDict([(key, new_value) if k == key else (k, v) for k, v in list(ret.items())])
             else:
                 new_key = expand_vars(key, params, vault, vault_keys)
                 new_value = expand_vars(value, params, vault, vault_keys)
-                ret = OrderedDict(
-                    [
-                        (new_key, new_value) if k == key else (k, v)
-                        for k, v in list(ret.items())
-                    ]
-                )
+                ret = OrderedDict([(new_key, new_value) if k == key else (k, v) for k, v in list(ret.items())])
         return ret
     if isinstance(line, list):
         return [expand_vars(x, params, vault, vault_keys) for x in line]
-    if isinstance(line, six.string_types):
+    if isinstance(line, str):
         ret = _apply_simple_regex(SIMPLE_PARAM_RE, line, params, vault, vault_keys)
         if isinstance(ret, OrderedDict):
             return expand_vars(ret, params, vault, vault_keys)
@@ -294,28 +258,14 @@ def expand_only_double_paranthesis_params(line, params, vault, vault_keys):
     if isinstance(line, OrderedDict) or isinstance(line, dict):
         ret = OrderedDict(list(line.items()))
         for key, value in list(line.items()):
-            new_key = expand_only_double_paranthesis_params(
-                key, params, vault, vault_keys
-            )
-            new_value = expand_only_double_paranthesis_params(
-                value, params, vault, vault_keys
-            )
-            ret = OrderedDict(
-                [
-                    (new_key, new_value) if k == key else (k, v)
-                    for k, v in list(ret.items())
-                ]
-            )
+            new_key = expand_only_double_paranthesis_params(key, params, vault, vault_keys)
+            new_value = expand_only_double_paranthesis_params(value, params, vault, vault_keys)
+            ret = OrderedDict([(new_key, new_value) if k == key else (k, v) for k, v in list(ret.items())])
         return ret
     if isinstance(line, list):
-        return [
-            expand_only_double_paranthesis_params(x, params, vault, vault_keys)
-            for x in line
-        ]
-    if isinstance(line, six.string_types):
-        ret = _apply_simple_regex(
-            DOUBLE_PARANTHESIS_RE, line, params, vault, vault_keys
-        )
+        return [expand_only_double_paranthesis_params(x, params, vault, vault_keys) for x in line]
+    if isinstance(line, str):
+        ret = _apply_simple_regex(DOUBLE_PARANTHESIS_RE, line, params, vault, vault_keys)
         if isinstance(ret, OrderedDict):
             return expand_only_double_paranthesis_params(ret, params, vault, vault_keys)
         return ret
@@ -352,16 +302,12 @@ def _process_line_re(line, params, vault, vault_keys, matcher):
         else:
             next_start = match.end()
         if name_arg:
-            if param_value and (
-                PARAM_RE.search(param_value) or SIMPLE_PARAM_RE.search(param_value)
-            ):
+            if param_value and (PARAM_RE.search(param_value) or SIMPLE_PARAM_RE.search(param_value)):
                 param_value = None
                 next_start = match.end()
             else:
                 param_value = VAR_OPERATIONS[name_arg[2]](param_value, name_arg[1])
-        if isinstance(param_value, NoneType) or isinstance(
-            param_value, ParamNotAvailable
-        ):
+        if isinstance(param_value, NoneType) or isinstance(param_value, ParamNotAvailable):
             next_start = match.end()
         else:
             if not (ret[: match.start()] + ret[match.end() :]).strip():
@@ -380,9 +326,7 @@ def _var_default(value, arg):
 
 def _var_suffix(value, arg):
     if value:
-        return re.sub(
-            "^" + re.escape(arg[::-1]).replace("\\*", ".*?"), "", value[::-1]
-        )[::-1]
+        return re.sub("^" + re.escape(arg[::-1]).replace("\\*", ".*?"), "", value[::-1])[::-1]
     return value
 
 
@@ -394,9 +338,7 @@ def _var_prefix(value, arg):
 
 def _var_suffix_greedy(value, arg):
     if value:
-        return re.sub("^" + re.escape(arg[::-1]).replace("\\*", ".*"), "", value[::-1])[
-            ::-1
-        ]
+        return re.sub("^" + re.escape(arg[::-1]).replace("\\*", ".*"), "", value[::-1])[::-1]
     return value
 
 
@@ -493,7 +435,7 @@ def read_if_readable(filename):
                 return read_file.read()
         else:
             return ""
-    except:
+    except Exception:
         return ""
 
 
@@ -510,7 +452,7 @@ def session_token(duration_minutes=60, token_arn=None, token_value=None):
     ret = {}
     try:
         ret = sts().get_session_token(**args)
-    except:
+    except Exception:
         pass
     if "Credentials" not in ret:
         return None
